
%clear workspace
%close all;
clear all;

%% Definition of initial concentration & volumes & mol. mass & simulation time

NrSpecies = 4;

Vol = 100;
% Reaction volumes of each species in units [L]
V = zeros(NrSpecies,1);
V(1) = Vol ;% reaction volume of X1
V(2) = Vol ;% reaction volume of X2
V(3) = Vol ;% reaction volume of X3
V(4) = Vol ;% reaction volume of X4

X0 = zeros(NrSpecies,1);
% Initial conditions
% in [mole]
X0(1) = 1e3;% X1 Substrate 
X0(2) = 3;  % X2 Enzyme
X0(3) = 0;  % X3 Complex 
X0(4) = 0;  % X4 Product

x0 = X0./V;

% % avogadro constant
% Na = 6.022e23; % [molecules/mol]
% 
% %molecular weights [g/mol]
% MW = zeros(NrSpecies,1);
% MW(1) = 6;
% MW(2) = 10;
% MW(3) = MW(1)+MW(2);%complex
% MW(4) = 6;

% Simulations time
Simtime = 1000; %[min]
% accuracy of ODE solver
RTol = 1e-4; %relative tolerance
ATol = 1e-6; % absolute tolerance



%% Definition of model reactions (only constant constituents)

% Model reactions
global NrReactions
NrReactions = 4;

% Stoichiometric Matrix 
% unit: # of molecules/moles changed by reaction
global S
S = zeros(NrSpecies,NrReactions);
%          X1   X2  X3  X4
S(:,1) = [-1;   -1;  1;  0]; %r1
S(:,2) = [ 1;  1; -1;  0]; %r2
S(:,3) = [ 0;   1;  -1;  1]; %r3
S(:,4) = [-1;   0;  0; 0]; %r4

% reaction parameters 
global k
k = ones(NrReactions,1);
k(1) = 0.1; %kon; unit [L^2/mole*min]
k(2) = 0.05; %koff; unit [L/min]
k(3) = 10;%kcat; unit [L/min]
k(4) = 0.01; %kdeg;


%% Simulate
%settings of the ODE solver (mass balance equations, accuracy (relative, absolute))
options = odeset('Mass',diag(V),'RelTol',RTol,'AbsTol',ATol,'NonNegative',ones(NrSpecies,1)); 
[t,x] = ode15s(@RHS,[0 Simtime],x0,options);

figure(2)
subplot(2,2,1)
plot(t,x(:,1))
  title('S')
subplot(2,2,2)
plot(t,x(:,2))
  title('E')
subplot(2,2,3)
plot(t,x(:,3))
  title('ES')
subplot(2,2,4)
plot(t,x(:,4))
  title('P')
% xlabel('time [min]')
% ylabel('concentrations [mol/L]')
% legend('X1','X2','X3','X4')
% PlotNicely(2)



